# Data Repository

This documentation was generated according to the questions in https://www.cessda.eu/Training/Training-Resources/Library/Data-Management-Expert-Guide/2.-Organise-Document/Documentation-and-metadata




## 1. For what purpose was the data created

### The title of the project

Dynamic modelling of phosphorolytic cleavage catalyzed by pyrimidine-nucleoside phosphorylase

### Subtitle

Collection of UV/vis spectra for monitoring of reaction progress with varying reactant concentrations

### Author(s)/creator(s) of the dataset

Niels J. Krausch (https://orcid.org/0000-0003-2325-6001)

### Other co-workers and their roles (person, research group or organization that participated in the study and their roles)

Robert T. Giessmann (https://orcid.org/0000-0002-0254-1500; supervision and packaging of data set)

### The institution of the author(s)/creator(s)

TU Berlin

###    Funders

- German Research Foundation (DFG)
- Einstein Foundation Berlin (ESB)

###    Grant numbers

- German Research Foundation (DFG) under Germany´s Excellence Strategy – EXC 2008/1– 390540038 (UniSysCat)
- Einstein Foundation Berlin (ESB) - Einstein Center of Catalysis (EC²)

###    References to related projects

None.

###    Publications from the data.

Robert T. Giessmann, Niels Krausch, Felix Kaspar, Mariano Nicolas Cruz Bournazou, Anke Wagner, Peter Neubauer and Matthias Gimpel "Dynamic modelling of phosphorolytic cleavage catalyzed by pyrimidine-nucleoside phosphorylase". MDPI Processes 2019, submitted.




## 2. What does the dataset contain?

###    Kind of data (interviews, images, questionnaires, etc.)

- Raw spectra of samples processed during the project
- Processed spectra
- Provenance documents, i.e. lab journal
- Metadata regarding experimental conditions leading to acquired spectra

###    file format of the data files and relationships between files

- Raw spectra are given in proprietary .xpt format used by BioTek's Gen5 Software (version 1.11.5)
- Processed spectra are given in a tabular format as tab separated values (.tsv)
- Provenance documents are given in .jpg image format
- Metadata is given in tabular format as comma separated values (.csv)

###    Description of data file(s): version and edition, structure of the database, associations, links between files, external links, formats, compatibility.

Data is organized into folders according to its type: "raw_data", "treated_data", "provenance", "metadata". Data is given per date, i.e. day, of data collection, if applicable.

Deriving from the filename in raw_data, treated_data files are named similar but with an extension (e.g. "\_Spectrum") corresponding to its content. If necessary, those extended filenames are organized further into directories ("Pathlength_corr" for the measurements to enable pathlength correction by 977 / 900 nm data, "Mes_repeat" for measurements of the same sample after further experimental treatment, i.e. centrifugation as described in the provenance documents).

Description of individual files:

- metadata/metadata-experimental-conditions.csv
  - Entry: arbitrary index
  - base1: initial concentration of thymine in the reaction mixture, given in mM
  - nucl1: initial concentration of deoxythymidine in the reaction mixture, given in mM
  - phos: initial concentration of phosphate in the reaction mixture, given in mM
  - enz in uL: volume of enzyme solution added to the reaction mixture, given in uL, indirectly linked to column "enz1"
  - R1P: initial concentration of deoxyribose-1-phosphate in the reaction mixture, given in mM
  - enz1_comp_ENP: initial concentration of enzyme complex in the reaction mixture, given in mM
  - enz1: initial concentration of free enzyme in the reaction mixture, given in mM
  - description_1: an arbitrary description, here used for numbering similar to the corresponding publication
  - description: unique identifier of the experimental condition instance, linked to metadata/metadata-spectra.csv:Condition_Name
  - description_2: an arbitrary description, here used for indication of experimental condition and corresponding replicates
  - filename: used for internal purposes only
  - sheetname: used for internal purposes only
  - data_starts_in_row: used for internal purposes only
  - data_is_in_columns: used for internal purposes only
  - names_of_data_columns: used for internal purposes only
  - data_length_in_rows: used for internal purposes only
  - factor_t: used for internal purposes only
  - offset_t: used for internal purposes only

- metadata/metadata-spectra.csv
  - Condition_Name: foreign key of the experimental condition instance, linked to metadata/metadata-experimental-conditions.csv:description
  - Unique_Sample_ID: unique identifier of each sample
  - Data_File: indicates the file the spectrum can be found in, indirectly linked to filenames in raw_data respectively treated_data
  - Well_Number: for the given Data_File, indicates which well number corresponds to this sample
  - Blank_Unique_Sample_ID: foreign key of the corresponding blank measurement, linked to Unique_Sample_ID
  - Replicate: used for internal purposes only
  - Wavelength_Start: used for internal purposes only
  - Wavelength_End: used for internal purposes only
  - Is_neg_ctrl: used for internal purposes only
  - Time_Point: indicates the time point of sampling, given in minutes
  - Description: arbitrary description, here used for indication of experimental condition and corresponding replicates (indirectly linked to metadata/metadata-experimental-conditions.csv:description_2)
  - Total_Concentration: the total concentration of UV/Vis active substances, equals to the sum of metadata/metadata-experimental-conditions.csv:base1 and metadata/metadata-experimental-conditions.csv:nucl1
  - Include_In_Parameter_Estimation: used for internal purposes only
  - Reference_Spectrum_deoxythymidine: used for internal purposes only
  - Reference_Spectrum_thymine: used for internal purposes only




## 3. How was data collected?

Describe how the data was acquired:

###    The methodology and technique used in collecting and creating the data

UV/Vis spectroscopy was used after dilution of reaction mixture samples into alkaline solution.

###    Description of all the sources the data originate from (What is the subject of study? E.g. periodicals, datasets created by others?) together with an explanation of how and why it got to the present place (provenance)

This data set contains only original data.

###    The methods/modes of data collection

For the exact methodology, cf. the cited publication, which is quoted here:

~~~
2. Materials and Methods

2.1. Materials

All chemicals used in this study were of analytical grade and used without further purification. The water used in all solutions was deionized to 18.2 MΩ∙cm with a water purification system from Werner. Deoxythymidine was purchased from Carbosynth. Thymine and phosphate (KH2PO4) were purchased from Sigma-Aldrich. Tris (2-Amino-2-(hydroxymethyl)propane-1,3-diol) was of buffer grade and purchased from Carl Roth.

Tris buffer was prepared as a 50 mM solution and pH was adjusted to 9.0 using 1 M HCl. Phosphate was prepared as a 1 M stock solution in 50 mM Tris buffer and pH was subsequently adjusted to 9.0 using 1 M NaOH. Deoxythymidine and thymine stock solutions were prepared in different concentrations (ranging from 1 to 10 mM) in 50 mM Tris buffer and treated with ultrasound to facilitate full dissolution.

The enzyme under investigation is a Py-NPase (EC 2.4.2.2, NCBI sequence accession number WP_041270053.1) from Geobacillus thermoglucosidasius (DSM No.: 2542). After IPTG-induced recombinant overexpression, the N-terminally His6-tagged Py-NPase was purified from E. coli BL21 using Ni-NTA affinity chromatography as described previously [17]. Purity was determined by SDS-PAGE analysis and found to be > 90%. Subsequently, the enzyme was dialyzed against 2 mM potassium phosphate buffer, pH 7.0 (measured at 25 °C) and stored until use at +4 °C at a concentration of 3.69 mg/mL as judged by NanoDrop analysis (calculated with 0.48 AU at 280 nm = 1 mg/mL). One unit (1 U) of enzyme activity was defined as the conversion of 1 µmol of deoxythymidine per minute in a 1 mL assay mixture of 2 mM deoxythymidine and 75 mM phosphate in 50 mM Tris buffer at a reaction temperature of 40 °C and at pH = 9.0 (measured at 25 °C), as determined by the method described later. The molecular weight of the enzyme was calculated from its amino acid sequence to be 47.6 kDa. The used enzyme preparation had an activity of approximately 0.46 U / mg.

UV/Vis transparent 96-well plates (UV-STAR F-Bottom #655801, purchased from Greiner Bio-One) were used to host the solutions for UV/Vis spectroscopy.


2.2. Experimental

Phosphate and deoxythymidine concentrations were varied in the range of 2 to 80 mM, and 0.8 to 5 mM, respectively, in the assay mixture. Final enzyme concentration in the assay mixture was in the range of 12.5 µg/mL to 50 µg/mL. This corresponds to an enzyme monomer concentration of 0.26 µM to 1.05 µM as calculated from its molecular weight.

Reaction mixtures were prepared in 1.5 mL microreaction tubes. Appropriate amounts of phosphate and deoxythymidine stock solutions were added to an appropriate amount of the 50 mM Tris solution. All components were mixed by vortexing, and the microreaction tube preheated for at least 5 minutes in an Eppendorf ThermoStat Plus. Subsequently, enzyme stock solution was added to the tube, which was mixed by slight inversions. At given timepoints, a 60 µL sample was removed from the microreaction tube and injected immediately into 940 µL of 0.2 M NaOH solution in a separate tube to stop the reaction and to dilute the sample simultaneously. After vortexing, 300 µL of the diluted mixture was transferred into UV/Vis transparent 96 well plates. When the concentration of UV/Vis absorbing compound, i.e. deoxythymidine or thymine, was varied, the sampling volume was adjusted as appropriate to give a constant final concentration of approximately 60 µM UV/Vis absorbing compounds in the alkaline dilutions to generate a UV/Vis absorption in the linear range, i.e. 0–1 AU at 260 nm. The ratio of substrate and product was determined by fitting the spectral 277/300 nm ratio (see below).

UV/Vis absorption spectra were recorded with a PowerWave HT or Synergy MX (BioTek Instruments) in the range from 250 nm to 350 nm in 1 nm steps. Spectra were corrected for blanks, i.e. 0.2 M NaOH solution, recorded within each set of measurements.


2.3. Spectroscopic Determination of Deoxythymidine/Thymine Ratio

The deoxythymidine/thymine ratio was determined with a spectrophotometric assay, modified from [18]. In extension to previous versions of this assay, the spectra were normalized to the isosbestic point of deoxythymidine-thymine mixtures as suggested by [19], which we determined to be at 277 nm. This increased robustness against random dilution errors [20], as they commonly appear in high-throughput experimentation.

Briefly, the spectrum was first blank-corrected by subtracting a spectrum of 0.2 M NaOH, and subsequently divided by its absorption at the isosbestic point to normalize the spectrum at this position to “1”. Then, the normalized absorption at 300 nm was considered as a proxy of the deoxythymidine/thymine ratio.
 Thus, the measured absorption ratio Abs300/277 = Abs300 / Abs277 was fitted by a linear relationship without intercept:

          Abs300/277(experimental) = x * Abs300/277(deoxythymidine) + (1 − x) * Abs300/277(thymine)

 where x is the mole fraction of deoxythymidine in the mixture. From pure compound spectra we determined Abs300/277(deoxythymidine) = 0.005115 and Abs300/277(thymine) = 0.772973.

 The algorithms and data treatment functions were implemented in Python.
~~~



## 4. Who collected the data and when?

###    Data collector(s)

Niels Jonas Krausch, TU Berlin

###    Date of data collection

23.-27.07.2018.

###    Geographical coverage of the data (e.g. Nation)

Does not apply.





## 5. How was the data processed?

### Describe your workflow and specific tools, instruments, procedures, hardware/software or protocols you might have used to process the data

No data processing was applied in this data set. If deemed necessary from inspection of the absorption at wavelengths > 320 nm (expected value: 0.035), the samples were centrifuged and carefully pipetted supernatant was measured in a new well.




## 6. What possible manipulations were done to the data?

### Describe if and how the data were manipulated or modified:

None.




## 7. What were the quality assurance procedures?

Describe how the quality of the data has been assured:

###    Checking for equipment and transcription errors

The plate reader performed routine system-testing before every set of measurements. No errors were reported by the software.

###    Quality control of materials

The materials were used as provided.

###    Data integrity checks

The data integrity was checked by visual inspection for plausability.

###    Calibration procedures

Calibration was performed by the plate reader with internal standards.

###    Data capture resolution and repetitions

See the corresponding publication or the metadata of experimental conditions. Every experimental condition was tested in duplicates. Inter-day control was performed by testing a similar condition every day (condition "General Center").

### Other procedures related to data quality such as weighting, calibration, reasons for missing values, checks and corrections of transcripts, transformations.

None.




## 8. How can the data be accessed?

Describe the use and access conditions of the data:

###    Where the data can be found (which data repository)

...

###    Permanent identifiers

...

###    Access conditions such as embargo

No embargo applies.

###    Parts of the data that are restricted or protected

No restriction or protection applies.

###    Licences

This work is licensed under a Creative Commons Attribution 4.0 International License.

This is a human-readable summary of (and not a substitute for) the license:

~~~
You are free to:

    Share — copy and redistribute the material in any medium or format
    Adapt — remix, transform, and build upon the material
    for any purpose, even commercially.

This license is acceptable for Free Cultural Works.

    The licensor cannot revoke these freedoms as long as you follow the license terms.

Under the following terms:

    Attribution — You must give appropriate credit, provide a link to the license, and indicate if changes were made. You may do so in any reasonable manner, but not in any way that suggests the licensor endorses you or your use.

    No additional restrictions — You may not apply legal terms or technological measures that legally restrict others from doing anything the license permits.

 Notices:

    You do not have to comply with the license for elements of the material in the public domain or where your use is permitted by an applicable exception or limitation.

    No warranties are given. The license may not give you all of the permissions necessary for your intended use. For example, other rights such as publicity, privacy, or moral rights may limit how you use the material.
~~~


You can find the full legal text of the license in the file LICENSE.md and (translated in most languages as well) at https://creativecommons.org/licenses/by/4.0/

###    Data confidentiality

Does not apply.

###    Copyright and ownership issues

Does not apply.

###    Citation information.

Please cite this data set as:

...
